@@ -23,6 +23,7 @@
 
 #include "config.h"
 
+#include <stdlib.h>
 #include <string.h>
 
 #include "peas-i18n-priv.h"
@@ -143,19 +144,62 @@ plugin_info_add_sorted (GQueue         *plugin_list,
         }
     }
 
-  /* GLib changed only accepts NULL for
-   * g_queue_insert_after() at version 2.44
-   */
   if (furthest_dep == NULL)
     {
-      g_queue_push_head (plugin_list, info);
-      return;
+      /* If we have dependencies and we didn't find any matches yet,
+       * then push the item to the tail to improve the chances that
+       * the dependencies will resolve in the proper order. Otherwise
+       * a plugin that has dependency (which also has a dependency)
+       * can resolve in the wrong order. To slightly improve on this
+       * we can also look for any plugins that depend on this and
+       * insert it before that iter.
+       *
+       * Another option here is to do proper dependency solving but
+       * the way things are designed to do resolving at each info
+       * load means that we'd do the depsolve more than necessary.
+       */
+      if (dependencies[0] == NULL)
+        {
+          g_queue_push_head (plugin_list, info);
+          return;
+        }
+      else
+        {
+          const char *module_name = peas_plugin_info_get_module_name (info);
+          GList *iter;
+
+          for (iter = plugin_list->head; iter; iter = iter->next)
+            {
+              const PeasPluginInfo *other = iter->data;
+              const char **other_dependencies = peas_plugin_info_get_dependencies (other);
+
+              for (i = 0; other_dependencies[i] != NULL; i++)
+                {
+                  if (strcmp (other_dependencies[i], module_name) == 0)
+                    {
+                      g_queue_insert_before (plugin_list, iter, info);
+                      return;
+                    }
+                }
+            }
+
+          g_queue_push_tail (plugin_list, info);
+          return;
+        }
     }
 
   g_debug ("Adding '%s' after '%s' due to dependencies",
            peas_plugin_info_get_module_name (info),
            peas_plugin_info_get_module_name (furthest_dep->data));
 
+  /* GLib only accepts NULL for g_queue_insert_after() at
+   * version 2.44 and above so make sure NULL is handled
+   * before reaching here.
+   */
+#if !GLIB_CHECK_VERSION(2,44,0)
+  g_assert (furthest_dep != NULL);
+#endif
+
   g_queue_insert_after (plugin_list, furthest_dep, info);
 }
 
@@ -241,6 +285,16 @@ load_file_dir_real (PeasEngine  *engine,
   return found;
 }
 
+static int
+strptrcmp (gconstpointer a,
+           gconstpointer b)
+{
+  const char * const *stra = a;
+  const char * const *strb = b;
+
+  return strcmp (*stra, *strb);
+}
+
 static gboolean
 load_resource_dir_real (PeasEngine  *engine,
                         const gchar *module_dir,
@@ -267,6 +321,9 @@ load_resource_dir_real (PeasEngine  *engine,
       return FALSE;
     }
 
+  /* Always sort resource children for improved reproducibility */
+  qsort (children, g_strv_length (children), sizeof (char *), strptrcmp);
+
   for (i = 0; children[i] != NULL; ++i)
     {
       gboolean is_dir;
