@@ -21,38 +21,29 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n.h>
 #include <string.h>
 
-#include "peas-i18n.h"
 #include "peas-dirs.h"
 
-/**
- * peas_gettext:
- * @msgid: The string to be translated
- *
- * Returns the translated string from the libpeas translations.
- * This is an internal function and should only be used by
- * the internals of libpeas (such as libpeas or libpeas-gtk).
- *
- * Returns: the transation of @msgid to the current locale
- */
-const gchar *
-peas_gettext (const gchar *msgid)
+#include "gconstructor.h"
+
+#if defined (G_HAS_CONSTRUCTORS)
+# ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
+#  pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(peas_init_ctor)
+# endif
+G_DEFINE_CONSTRUCTOR(peas_init_ctor)
+#else
+# error Your platform/compiler is missing constructor support
+#endif
+
+static void
+peas_init_ctor (void)
 {
-  static gboolean initialized = FALSE;
+  gchar *locale_dir = peas_dirs_get_locale_dir ();
 
-  if (G_UNLIKELY (!initialized))
-    {
-      gchar *locale_dir;
+  bindtextdomain (GETTEXT_PACKAGE, locale_dir);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
-      locale_dir = peas_dirs_get_locale_dir ();
-
-      (void) bindtextdomain (GETTEXT_PACKAGE, locale_dir);
-      g_free (locale_dir);
-
-      (void) bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-      initialized = TRUE;
-    }
-
-  return g_dgettext (GETTEXT_PACKAGE, msgid);
+  g_free (locale_dir);
 }
