@@ -26,6 +26,7 @@
 #include <stdlib.h>
 
 #include <glib.h>
+#include <glib-object.h>
 #include <libpeas/peas.h>
 
 #include "testing/testing.h"
@@ -146,6 +147,48 @@ test_extension_set_create_valid (PeasEngine *engine)
   g_object_unref (extension_set);
 }
 
+static void
+valid_extension_added_cb (PeasExtensionSet *extension_set,
+                          PeasPluginInfo   *info,
+                          PeasExtension    *extension,
+                          GObject          **obj_ptr)
+{
+  g_object_get (PEAS_ACTIVATABLE (extension), "object", obj_ptr, NULL);
+}
+
+static void
+test_extension_set_create_valid_with_properties (PeasEngine *engine)
+{
+  PeasPluginInfo *info;
+  PeasExtensionSet *extension_set;
+  GValue prop_value = G_VALUE_INIT;
+  GObject *obj, *obj_cmp;
+  const gchar *prop_names[1] = { "object" };
+
+  obj = g_object_new (G_TYPE_OBJECT, NULL);
+  g_value_init (&prop_value, G_TYPE_OBJECT);
+  g_value_set_object (&prop_value, obj);
+
+  extension_set = peas_extension_set_new_with_properties (engine,
+                                                          PEAS_TYPE_ACTIVATABLE,
+                                                          G_N_ELEMENTS (prop_names),
+                                                          prop_names,
+                                                          &prop_value);
+  g_signal_connect (extension_set,
+                    "extension-added",
+                    G_CALLBACK (valid_extension_added_cb),
+                    &obj_cmp);
+  info = peas_engine_get_plugin_info (engine, "builtin");
+
+  g_assert (peas_engine_load_plugin (engine, info));
+  g_assert (obj == obj_cmp);
+
+  g_assert (PEAS_IS_EXTENSION_SET (extension_set));
+  g_object_unref (extension_set);
+  g_value_unset (&prop_value);
+}
+
+
 static void
 test_extension_set_create_invalid (PeasEngine *engine)
 {
@@ -172,6 +215,62 @@ test_extension_set_create_invalid (PeasEngine *engine)
   g_assert (!PEAS_IS_EXTENSION_SET (extension_set));
 }
 
+static void
+test_extension_set_create_invalid_with_properties (PeasEngine *engine)
+{
+  PeasExtensionSet *extension_set;
+  GValue prop_values[2] = { G_VALUE_INIT };
+  const gchar *prop_names[2] = { "object", NULL };
+  const gchar *prop_names_not_exist[1] = { "aleb" };
+  guint n_elements;
+
+  testing_util_push_log_hook ("*property name*should not be NULL.");
+  testing_util_push_log_hook ("*assertion*G_TYPE_IS_INTERFACE*failed");
+  testing_util_push_log_hook ("*should be an initialized GValue.");
+  testing_util_push_log_hook ("*has no property named 'aleb'*");
+
+  g_value_init (&prop_values[0], G_TYPE_POINTER);
+  g_value_set_pointer (&prop_values[0], NULL);
+
+  /* Interface has a NULL property name*/
+  n_elements = G_N_ELEMENTS (prop_values);
+  extension_set = peas_extension_set_new_with_properties (engine,
+                                                          PEAS_TYPE_ACTIVATABLE,
+                                                          n_elements,
+                                                          prop_names,
+                                                          prop_values);
+  g_assert (!PEAS_IS_EXTENSION_SET (extension_set));
+  g_value_unset (&prop_values[0]);
+
+  /* Invalid GType */
+  extension_set = peas_extension_set_new_with_properties (engine,
+                                                          G_TYPE_INVALID,
+                                                          0, NULL, NULL);
+  g_assert (!PEAS_IS_EXTENSION_SET (extension_set));
+
+  /* Uninitialized GValue */
+  n_elements = 1;
+  extension_set = peas_extension_set_new_with_properties (engine,
+                                                          PEAS_TYPE_ACTIVATABLE,
+                                                          n_elements,
+                                                          prop_names,
+                                                          prop_values);
+  g_assert (!PEAS_IS_EXTENSION_SET (extension_set));
+
+  /* Uninitialized GValue*/
+  g_value_init (&prop_values[0], G_TYPE_POINTER);
+  g_value_set_pointer (&prop_values[0], NULL);
+  n_elements = G_N_ELEMENTS (prop_names_not_exist);
+  extension_set = peas_extension_set_new_with_properties (engine,
+                                                          PEAS_TYPE_ACTIVATABLE,
+                                                          n_elements,
+                                                          prop_names_not_exist,
+                                                          prop_values);
+  g_assert (!PEAS_IS_EXTENSION_SET (extension_set));
+  g_value_unset (&prop_values[0]);
+}
+
+
 static void
 test_extension_set_extension_added (PeasEngine *engine)
 {
@@ -345,6 +444,8 @@ main (int    argc,
 
   TEST ("create-valid", create_valid);
   TEST ("create-invalid", create_invalid);
+  TEST ("create-valid-with-properties", create_valid_with_properties);
+  TEST ("create-invalid-with-properties", create_invalid_with_properties);
 
   TEST ("extension-added", extension_added);
   TEST ("extension-removed", extension_removed);
