@@ -4,19 +4,19 @@
  *
  * Copyright (C) 2010 - Garrett Regier
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * libpeas is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * libpeas is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,9 +31,9 @@
 
 #include "self-dep-plugin.h"
 
-struct _TestingSelfDepPluginPrivate {
+typedef struct {
   GObject *object;
-};
+} TestingSelfDepPluginPrivate;
 
 static void peas_activatable_iface_init (PeasActivatableInterface *iface);
 
@@ -41,9 +41,13 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (TestingSelfDepPlugin,
                                 testing_self_dep_plugin,
                                 PEAS_TYPE_EXTENSION_BASE,
                                 0,
+                                G_ADD_PRIVATE_DYNAMIC (TestingSelfDepPlugin)
                                 G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
                                                                peas_activatable_iface_init))
 
+#define GET_PRIV(o) \
+  (testing_self_dep_plugin_get_instance_private (o))
+
 enum {
   PROP_0,
   PROP_OBJECT
@@ -56,11 +60,12 @@ testing_self_dep_plugin_set_property (GObject      *object,
                                       GParamSpec   *pspec)
 {
   TestingSelfDepPlugin *plugin = TESTING_SELF_DEP_PLUGIN (object);
+  TestingSelfDepPluginPrivate *priv = GET_PRIV (plugin);
 
   switch (prop_id)
     {
     case PROP_OBJECT:
-      plugin->priv->object = g_value_get_object (value);
+      priv->object = g_value_get_object (value);
       break;
 
     default:
@@ -76,11 +81,12 @@ testing_self_dep_plugin_get_property (GObject    *object,
                                       GParamSpec *pspec)
 {
   TestingSelfDepPlugin *plugin = TESTING_SELF_DEP_PLUGIN (object);
+  TestingSelfDepPluginPrivate *priv = GET_PRIV (plugin);
 
   switch (prop_id)
     {
     case PROP_OBJECT:
-      g_value_set_object (value, plugin->priv->object);
+      g_value_set_object (value, priv->object);
       break;
 
     default:
@@ -92,9 +98,6 @@ testing_self_dep_plugin_get_property (GObject    *object,
 static void
 testing_self_dep_plugin_init (TestingSelfDepPlugin *plugin)
 {
-  plugin->priv = G_TYPE_INSTANCE_GET_PRIVATE (plugin,
-                                              TESTING_TYPE_SELF_DEP_PLUGIN,
-                                              TestingSelfDepPluginPrivate);
 }
 
 static void
@@ -116,8 +119,6 @@ testing_self_dep_plugin_class_init (TestingSelfDepPluginClass *klass)
   object_class->get_property = testing_self_dep_plugin_get_property;
 
   g_object_class_override_property (object_class, PROP_OBJECT, "object");
-
-  g_type_class_add_private (klass, sizeof (TestingSelfDepPluginPrivate));
 }
 
 static void
